// index.ts
import fetch from "isomorphic-unfetch";
import { stringify } from "query-string";
var ACCESS_TOKEN_URL = "https://accounts.spotify.com/api/token";
var CURRENTLY_PLAYING_URL = `https://api.spotify.com/v1/me/player/currently-playing`;
var LAST_PLAYED_URL = `https://api.spotify.com/v1/me/player/recently-played?limit=1`;
var filterResponse = (track) => {
  var _a;
  return {
    title: track == null ? void 0 : track.name,
    artist: (_a = track == null ? void 0 : track.artists) == null ? void 0 : _a.map((artist) => artist == null ? void 0 : artist.name).join(", "),
    link: track == null ? void 0 : track.external_urls.spotify
  };
};
var encodeToBase64 = (str) => Buffer.from(str).toString("base64");
var SpotifyClient = class {
  constructor({ clientId, clientSecret, refreshToken }) {
    this._genAccesToken = async () => {
      const basicToken = encodeToBase64(`${this.clientId}:${this.clientSecret}`);
      const response = await fetch(ACCESS_TOKEN_URL, {
        method: "POST",
        headers: {
          Authorization: `Basic ${basicToken}`,
          "Content-Type": "application/x-www-form-urlencoded"
        },
        body: stringify({
          grant_type: "refresh_token",
          refresh_token: this.refreshToken
        })
      });
      const responseData = await response.json();
      return responseData == null ? void 0 : responseData.access_token;
    };
    this.getCurrentlyPlaying = async () => {
      try {
        const accessToken = await this._genAccesToken();
        const headers = { Authorization: `Bearer ${accessToken}` };
        const response = await fetch(CURRENTLY_PLAYING_URL, { headers });
        if (response.status === 204)
          return null;
        const responseData = await response.json();
        const currentTrack = filterResponse(responseData == null ? void 0 : responseData.item);
        return currentTrack;
      } catch (error) {
        throw new Error(error);
      }
    };
    this.getLastPlayed = async () => {
      var _a;
      try {
        const accessToken = await this._genAccesToken();
        const headers = { Authorization: `Bearer ${accessToken}` };
        const response = await fetch(LAST_PLAYED_URL, { headers });
        const responseData = await response.json();
        if (!response.ok)
          throw new Error(responseData);
        const lastPlayedTrack = filterResponse((_a = responseData == null ? void 0 : responseData.items[0]) == null ? void 0 : _a.track);
        return lastPlayedTrack;
      } catch (error) {
        throw new Error(error);
      }
    };
    this.clientId = clientId;
    this.clientSecret = clientSecret;
    this.refreshToken = refreshToken;
  }
};
export {
  SpotifyClient
};
